@@ -1,11 +1,9 @@
 from movement_detector.video import CvVideo
-from md_interface.interface import Interface
 from movement_detector.detectors import PixelChangeFD
 from movement_detector.analysis import IntervalAggregatorMA
 
 __all__ = [
     'CvVideo',
     'PixelChangeFD',
-    'Interface',
     'IntervalAggregatorMA',
 ]
